@@ -7,7 +7,8 @@
  ****************************************************************************/
 
 /*
- * Brasero is free software; you can redistribute it and/or modify
+ * Libbrasero-media is free software; you can redistribute it and/or modify
+fy
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -31,8 +32,11 @@
 #include <glib.h>
 #include <gmodule.h>
 
+#include "brasero-media-private.h"
+
 #include "burn-debug.h"
 #include "burn-track.h"
+#include "brasero-media.h"
 
 static gboolean debug = FALSE;
 
@@ -162,84 +166,6 @@ brasero_burn_debug_flags_type_message (BraseroBurnFlag flags,
 	g_free (format_real);
 }
 
-static void
-brasero_debug_medium_info_to_string (gchar *buffer,
-				     BraseroMedia media)
-{
-	if (media & BRASERO_MEDIUM_FILE)
-		strcat (buffer, "file ");
-
-	if (media & BRASERO_MEDIUM_CD)
-		strcat (buffer, "CD ");
-
-	if (media & BRASERO_MEDIUM_DVD)
-		strcat (buffer, "DVD ");
-
-	if (media & BRASERO_MEDIUM_RAM)
-		strcat (buffer, "RAM ");
-
-	if (media & BRASERO_MEDIUM_BD)
-		strcat (buffer, "BD ");
-
-	if (media & BRASERO_MEDIUM_DUAL_L)
-		strcat (buffer, "DL ");
-
-	/* DVD subtypes */
-	if (media & BRASERO_MEDIUM_PLUS)
-		strcat (buffer, "+ ");
-
-	if (media & BRASERO_MEDIUM_SEQUENTIAL)
-		strcat (buffer, "- (sequential) ");
-
-	if (media & BRASERO_MEDIUM_RESTRICTED)
-		strcat (buffer, "- (restricted) ");
-
-	if (media & BRASERO_MEDIUM_JUMP)
-		strcat (buffer, "- (jump) ");
-
-	/* BD subtypes */
-	if (media & BRASERO_MEDIUM_SRM)
-		strcat (buffer, "SRM ");
-
-	if (media & BRASERO_MEDIUM_POW)
-		strcat (buffer, "POW ");
-
-	if (media & BRASERO_MEDIUM_RANDOM)
-		strcat (buffer, "RANDOM ");
-
-	/* discs attributes */
-	if (media & BRASERO_MEDIUM_REWRITABLE)
-		strcat (buffer, "RW ");
-
-	if (media & BRASERO_MEDIUM_WRITABLE)
-		strcat (buffer, "W ");
-
-	if (media & BRASERO_MEDIUM_ROM)
-		strcat (buffer, "ROM ");
-
-	/* status of the disc */
-	if (media & BRASERO_MEDIUM_CLOSED)
-		strcat (buffer, "closed ");
-
-	if (media & BRASERO_MEDIUM_BLANK)
-		strcat (buffer, "blank ");
-
-	if (media & BRASERO_MEDIUM_APPENDABLE)
-		strcat (buffer, "appendable ");
-
-	if (media & BRASERO_MEDIUM_PROTECTED)
-		strcat (buffer, "protected ");
-
-	if (media & BRASERO_MEDIUM_HAS_DATA)
-		strcat (buffer, "with data ");
-
-	if (media & BRASERO_MEDIUM_HAS_AUDIO)
-		strcat (buffer, "with audio ");
-
-	if (media & BRASERO_MEDIUM_UNFORMATTED)
-		strcat (buffer, "Unformatted ");
-}
-
 static void
 brasero_debug_image_format_to_string (gchar *buffer,
 				      BraseroImageFormat format)
@@ -262,6 +188,8 @@ brasero_debug_data_fs_to_string (gchar *buffer,
 		strcat (buffer, "ISO ");
 	if (fs_type & BRASERO_IMAGE_FS_UDF)
 		strcat (buffer, "UDF ");
+	if (fs_type & BRASERO_IMAGE_FS_SYMLINK)
+		strcat (buffer, "SYMLINK ");
 	if (fs_type & BRASERO_IMAGE_ISO_FS_LEVEL_3)
 		strcat (buffer, "Level 3 ");
 	if (fs_type & BRASERO_IMAGE_FS_JOLIET)
@@ -332,7 +260,7 @@ brasero_burn_debug_track_type_message (BraseroTrackDataType type,
 		break;
 	case BRASERO_TRACK_TYPE_DISC:
 		strcpy (buffer, "Disc ");
-		brasero_debug_medium_info_to_string (buffer, subtype);
+		brasero_media_to_string (subtype, buffer);
 		break;
 	case BRASERO_TRACK_TYPE_AUDIO:
 		strcpy (buffer, "Audio ");
