@@ -75,6 +75,8 @@ struct _BraseroProcessPrivate {
 	GIOChannel *std_error;
 	GString *err_buffer;
 
+	gchar *working_directory;
+
 	GPid pid;
 	gint io_out;
 	gint io_err;
@@ -89,6 +91,7 @@ struct _BraseroProcessPrivate {
 static GObjectClass *parent_class = NULL;
 
 /* This is a helper function for plugins at load time */
+
 gboolean
 brasero_process_check_path (const gchar *name,
 			    gchar **error)
@@ -103,49 +106,31 @@ brasero_process_check_path (const gchar *name,
 		return BRASERO_BURN_ERR;
 	}
 
-	/* make sure that's not a symlink pointing to something with another
-	 * name like wodim. */
-	if (g_file_test (prog_path, G_FILE_TEST_IS_SYMLINK)) {
-		GFile *file;
-		GFileInfo *info;
-		gchar *prog_name;
-		const gchar *target;
-
-		file = g_file_new_for_path (prog_path);
+	if (!g_file_test (prog_path, G_FILE_TEST_IS_EXECUTABLE)) {
 		g_free (prog_path);
-
-		if (!file) {
-			*error = g_strdup_printf (_("\"%s\" could not be found in the path"), name);
-			return BRASERO_BURN_ERR;
-		}
-
-		info = g_file_query_info (file,
-					  G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET,
-					  G_FILE_QUERY_INFO_NONE,
-					  NULL,
-					  NULL);
-		g_object_unref (file);
-
-		if (!info) {
-			*error = g_strdup_printf (_("\"%s\" could not be found in the path"), name);
-			return BRASERO_BURN_ERR;
-		}
-
-		target = g_file_info_get_symlink_target (info);
-		prog_name = g_path_get_basename (target);
-		g_object_unref (info);
-
-		if (!prog_name || strcmp (prog_name, name)) {
-			g_free (prog_name);
-			*error = g_strdup_printf (_("\"%s\" is a symlink pointing to another program. Use the target program instead"), name);
-			return BRASERO_BURN_ERR;
-		}
-
-		g_free (prog_name);
+		*error = g_strdup_printf (_("\"%s\" could not be found in the path"), name);
+		return BRASERO_BURN_ERR;
 	}
-	else
-		g_free (prog_path);
 
+	/* make sure that's not a symlink pointing to something with another
+	 * name like wodim.
+	 * NOTE: we used to test the target and see if it had the same name as
+	 * the symlink with GIO. The problem is, when the symlink pointed to
+	 * another symlink, then GIO didn't follow that other symlink. And in
+	 * the end it didn't work. So forbid all symlink. */
+	if (g_file_test (prog_path, G_FILE_TEST_IS_SYMLINK)) {
+		*error = g_strdup_printf (_("\"%s\" is a symlink pointing to another program. Use the target program instead"), name);
+		g_free (prog_path);
+		return BRASERO_BURN_ERR;
+	}
+	/* Make sure it's a regular file */
+	else if (!g_file_test (prog_path, G_FILE_TEST_IS_REGULAR)) {
+		*error = g_strdup_printf (_("\"%s\" could not be found in the path"), name);
+		g_free (prog_path);
+		return BRASERO_BURN_ERR;
+	}
+
+	g_free (prog_path);
 	return BRASERO_BURN_OK;
 }
 
@@ -614,7 +599,12 @@ brasero_process_start (BraseroJob *job, GError **error)
 	if (result != BRASERO_BURN_OK)
 		return result;
 
-	BRASERO_JOB_LOG (process, "launching command");
+	if (priv->working_directory) {
+		BRASERO_JOB_LOG (process, "Launching command in %s", priv->working_directory);
+	}
+	else {
+		BRASERO_JOB_LOG (process, "Launching command");
+	}
 
 	klass = BRASERO_PROCESS_GET_CLASS (process);
 
@@ -623,7 +613,7 @@ brasero_process_start (BraseroJob *job, GError **error)
 		       brasero_job_get_fd_out (BRASERO_JOB (process), NULL) != BRASERO_BURN_OK);
 
 	priv->return_status = 0;
-	if (!g_spawn_async_with_pipes (NULL,
+	if (!g_spawn_async_with_pipes (priv->working_directory,
 				       (gchar **) priv->argv->pdata,
 				       (gchar **) envp,
 				       G_SPAWN_SEARCH_PATH|
@@ -681,11 +671,13 @@ brasero_process_stop (BraseroJob *job,
 		pid = priv->pid;
 		priv->pid = 0;
 
-		if (kill (pid, SIGTERM) == -1 && errno != ESRCH) {
+		/* Reminder: -1 is here to send the signal to all children of
+		 * the process with pid as well */
+		if (pid > 0 && kill ((-1) * pid, SIGTERM) == -1 && errno != ESRCH) {
 			BRASERO_JOB_LOG (process, 
 					 "process (%s) couldn't be killed: terminating",
 					 g_strerror (errno));
-			kill (pid, SIGKILL);
+			kill ((-1) * pid, SIGKILL);
 		}
 		else
 			BRASERO_JOB_LOG (process, "got killed");
@@ -784,6 +776,20 @@ brasero_process_stop (BraseroJob *job,
 	return result;
 }
 
+void
+brasero_process_set_working_directory (BraseroProcess *process,
+				       const gchar *directory)
+{
+	BraseroProcessPrivate *priv = BRASERO_PROCESS_PRIVATE (process);
+
+	if (priv->working_directory) {
+		g_free (priv->working_directory);
+		priv->working_directory = NULL;
+	}
+
+	priv->working_directory = g_strdup (directory);
+}
+
 static void
 brasero_process_finalize (GObject *object)
 {
@@ -840,6 +846,11 @@ brasero_process_finalize (GObject *object)
 		priv->error = NULL;
 	}
 
+	if (priv->working_directory) {
+		g_free (priv->working_directory);
+		priv->working_directory = NULL;
+	}
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
